@@ -1,5 +1,5 @@
 /*  xmms-shn - a shorten (.shn) plugin for XMMS
- *  Copyright (C) 2000-2001  Jason Jordan (shnutils@freeshell.org)
+ *  Copyright (C) 2000-2003  Jason Jordan <shnutils@freeshell.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  */
 
 /*
- * $Id: shn.h,v 1.6 2001/12/30 05:12:04 jason Exp $
+ * $Id: shn.h,v 1.15 2003/08/26 05:34:15 jason Exp $
  */
 
 #ifndef _SHN_H
@@ -42,6 +42,12 @@ extern char *sys_errlist[];
 #define strerror(x) sys_errlist[x]
 #endif
 
+#ifdef HAVE_VSNPRINTF
+#define shn_vsnprintf(a,b,c,d) vsnprintf(a,b,c,d)
+#else
+#define shn_vsnprintf(a,b,c,d) vsprintf(a,c,d)
+#endif
+
 #define	min(a,b)			(((a)<(b))?(a):(b))
 
 #define XMMS_SHN_VERSION_TAG		"xmms-shn_v2"
@@ -55,7 +61,7 @@ extern char *sys_errlist[];
 #define	ERROR_OUTPUT_STDERR		1
 #define	ERROR_OUTPUT_WINDOW		2
 
-#define	SEEK_SUFFIX			".skt"
+#define	SEEK_SUFFIX			"skt"
 
 #define	NO_SEEK_TABLE			-1
 
@@ -65,6 +71,7 @@ extern char *sys_errlist[];
 #define SEEK_HEADER_SIZE		12
 #define SEEK_TRAILER_SIZE		12
 #define SEEK_ENTRY_SIZE			80
+#define SEEK_RESOLUTION			25600
 
 #define WAVE_RIFF                       (0x46464952)     /* 'RIFF' in little-endian */
 #define WAVE_WAVE                       (0x45564157)     /* 'WAVE' in little-endian */
@@ -122,10 +129,16 @@ typedef struct _shn_config
 	gchar    *error_output_method_config_name;
 	gchar    *seek_tables_path;
 	gchar    *seek_tables_path_config_name;
+	gchar    *relative_seek_tables_path;
+	gchar    *relative_seek_tables_path_config_name;
 	gboolean  verbose;
 	gchar    *verbose_config_name;
 	gboolean  swap_bytes;
 	gchar    *swap_bytes_config_name;
+	gboolean  load_textfiles;
+	gchar	 *load_textfiles_config_name;
+	gchar	 *textfile_extensions;
+	gchar	 *textfile_extensions_config_name;
 } shn_config;
 
 typedef struct _shn_decode_state
@@ -222,6 +235,7 @@ typedef struct _shn_vars
 	int    eof;
 	int    going;
 	slong  seek_table_entries;
+	ulong  seek_resolution;
 	int    bytes_in_buf;
 	uchar  buffer[OUT_BUFFER_SIZE];
 	int    bytes_in_header;
@@ -244,23 +258,25 @@ extern InputPlugin shn_ip;
 extern shn_file *shnfile;
 extern shn_config shn_cfg;
 
-extern shn_seek_entry *seek_entry_search(shn_seek_entry *,ulong,ulong,ulong);
-extern void load_seek_table(shn_file *,char *);
-extern void unload_shn(shn_file *);
-extern void display_shn_about(void);
-extern void display_shn_configure(void);
-extern void display_shn_info(shn_file *);
-extern int verify_header(shn_file *);
-extern int filename_contains_a_dot(char *);
-extern void length_to_str(shn_file *);
-extern ulong uchar_to_ulong_le(uchar *);
-extern slong uchar_to_slong_le(uchar *);
-extern ushort uchar_to_ushort_le(uchar *);
-extern void convert_seek_tables_to_le(shn_file *);
-extern char *format_to_str(ushort);
-extern void message_box(char *);
-extern void debug(char *, ...);
-extern void error(char *, ...);
-extern void fatal_error(shn_file *,char *, ...);
+extern shn_seek_entry *shn_seek_entry_search(shn_seek_entry *,ulong,ulong,ulong,ulong);
+extern void shn_load_seek_table(shn_file *,char *);
+extern void shn_unload(shn_file *);
+extern void shn_display_about(void);
+extern void shn_display_configure(void);
+extern void shn_display_info(shn_file *);
+extern int shn_verify_header(shn_file *);
+extern int shn_filename_contains_a_dot(char *);
+extern char *shn_get_base_filename(char *);
+extern char *shn_get_base_directory(char *);
+extern void shn_length_to_str(shn_file *);
+extern ulong shn_uchar_to_ulong_le(uchar *);
+extern slong shn_uchar_to_slong_le(uchar *);
+extern ushort shn_uchar_to_ushort_le(uchar *);
+extern char *shn_format_to_str(ushort);
+extern void shn_message_box(char *);
+extern void shn_debug(char *, ...);
+extern void shn_error(char *, ...);
+extern void shn_error_fatal(shn_file *,char *, ...);
+extern void shn_snprintf(char *,int,char *, ...);
 
 #endif
