@@ -1,5 +1,5 @@
 /*  convert.c - functions to convert little-endian data to endian of host
- *  Copyright (C) 2000-2001  Jason Jordan (shnutils@freeshell.org)
+ *  Copyright (C) 2000-2003  Jason Jordan <shnutils@freeshell.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,25 +17,25 @@
  */
 
 /*
- * $Id: convert.c,v 1.4 2001/12/30 05:12:04 jason Exp $
+ * $Id: convert.c,v 1.7 2003/08/26 05:34:04 jason Exp $
  */
 
 #include <stdlib.h>
 #include "shorten.h"
 
-ulong uchar_to_ulong_le(uchar *buf)
+ulong shn_uchar_to_ulong_le(uchar *buf)
 /* converts 4 bytes stored in little-endian format to a ulong */
 {
 	return (ulong)((buf[3] << 24) + (buf[2] << 16) + (buf[1] << 8) + buf[0]);
 }
 
-slong uchar_to_slong_le(uchar *buf)
+slong shn_uchar_to_slong_le(uchar *buf)
 /* converts 4 bytes stored in little-endian format to an slong */
 {
-	return (slong)uchar_to_ulong_le(buf);
+	return (slong)shn_uchar_to_ulong_le(buf);
 }
 
-ushort uchar_to_ushort_le(uchar *buf)
+ushort shn_uchar_to_ushort_le(uchar *buf)
 /* converts 4 bytes stored in little-endian format to a ushort */
 {
 	return (ushort)((buf[1] << 8) + buf[0]);
