@@ -1,5 +1,5 @@
 /*  gtk.c - functions to build and display GTK windows
- *  Copyright (C) 2000-2001  Jason Jordan (shnutils@freeshell.org)
+ *  Copyright (C) 2000-2003  Jason Jordan <shnutils@freeshell.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  */
 
 /*
- * $Id: gtk.c,v 1.6 2001/12/30 05:12:04 jason Exp $
+ * $Id: gtk.c,v 1.20 2003/08/26 05:34:04 jason Exp $
  */
 
 #include <stdlib.h>
@@ -27,10 +27,25 @@
 #include <xmms/dirbrowser.h>
 #include "shorten.h"
 
+#undef XMMS_SHN_LOAD_TEXTFILES
+#ifdef HAVE_DIRENT_H
+#  include <sys/types.h>
+#  include <dirent.h>
+#  ifdef HAVE_OPENDIR
+#    ifdef HAVE_READDIR
+#      ifdef HAVE_CLOSEDIR
+#        define XMMS_SHN_LOAD_TEXTFILES 1
+#      endif
+#    endif
+#  endif
+#endif
+
 static GtkWidget *shn_configurewin = NULL,
 		 *about_box,
 		 *vbox,
 		 *options_vbox,
+		 *miscellaneous_vbox,
+		 *seektables_vbox,
 		 *bbox,
 		 *notebook,
 		 *output_frame,
@@ -43,6 +58,10 @@ static GtkWidget *shn_configurewin = NULL,
 		 *misc_vbox,
 		 *swap_bytes_toggle,
 		 *verbose_toggle,
+		 *textfile_toggle,
+		 *textfile_extensions_entry,
+		 *textfile_extensions_label,
+		 *textfile_extensions_hbox,
 		 *path_frame,
 		 *path_vbox,
 		 *path_label,
@@ -50,11 +69,14 @@ static GtkWidget *shn_configurewin = NULL,
 		 *path_entry_hbox,
 		 *path_browse,
 		 *path_dirbrowser = NULL,
+		 *relative_path_label,
+		 *relative_path_entry,
+		 *relative_path_entry_hbox,
 		 *ok,
 		 *cancel,
 		 *apply;
 
-void display_shn_about(void)
+void shn_display_about(void)
 {
 	if (about_box != NULL)
 	{
@@ -65,12 +87,12 @@ void display_shn_about(void)
 	about_box = xmms_show_message(
 		(gchar *) "About " PACKAGE,
 		(gchar *) PACKAGE " version " VERSION "\n"
-			  "Copyright 2001 Jason Jordan <shnutils@freeshell.org>\n"
+			  "Copyright 2000-2003 Jason Jordan <shnutils@freeshell.org>\n"
 			  "Portions Copyright (C) 1992-1995 Tony Robinson\n"
 			  "\n"
 			  "shorten utilities pages:\n"
 			  "\n"
-			  "http://shnutils.etree.org/\n"
+			  "http://www.etree.org/shnutils/\n"
 			  "http://shnutils.freeshell.org/",
 		(gchar *) "Cool",
 		FALSE, NULL, NULL);
@@ -114,10 +136,18 @@ void shn_configurewin_save(void)
 	g_free(shn_cfg.seek_tables_path);
 	shn_cfg.seek_tables_path = g_strdup(gtk_entry_get_text(GTK_ENTRY(path_entry)));
 
+	g_free(shn_cfg.relative_seek_tables_path);
+	shn_cfg.relative_seek_tables_path = g_strdup(gtk_entry_get_text(GTK_ENTRY(relative_path_entry)));
+
 	shn_cfg.verbose = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(verbose_toggle));
 
 	shn_cfg.swap_bytes = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(swap_bytes_toggle));
 
+	shn_cfg.load_textfiles = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(textfile_toggle));
+
+	g_free(shn_cfg.textfile_extensions);
+	shn_cfg.textfile_extensions = g_strdup(gtk_entry_get_text(GTK_ENTRY(textfile_extensions_entry)));
+
 	filename = g_strconcat(g_get_home_dir(), "/.xmms/config", NULL);
 	cfg = xmms_cfg_open_file(filename);
 	if (!cfg)
@@ -126,7 +156,10 @@ void shn_configurewin_save(void)
 	xmms_cfg_write_int(cfg, XMMS_SHN_VERSION_TAG, shn_cfg.error_output_method_config_name, shn_cfg.error_output_method);
 	xmms_cfg_write_boolean(cfg, XMMS_SHN_VERSION_TAG, shn_cfg.verbose_config_name, shn_cfg.verbose);
 	xmms_cfg_write_string(cfg, XMMS_SHN_VERSION_TAG, shn_cfg.seek_tables_path_config_name, shn_cfg.seek_tables_path);
+	xmms_cfg_write_string(cfg, XMMS_SHN_VERSION_TAG, shn_cfg.relative_seek_tables_path_config_name, shn_cfg.relative_seek_tables_path);
 	xmms_cfg_write_boolean(cfg, XMMS_SHN_VERSION_TAG, shn_cfg.swap_bytes_config_name, shn_cfg.swap_bytes);
+	xmms_cfg_write_boolean(cfg, XMMS_SHN_VERSION_TAG, shn_cfg.load_textfiles_config_name, shn_cfg.load_textfiles);
+	xmms_cfg_write_string(cfg, XMMS_SHN_VERSION_TAG, shn_cfg.textfile_extensions_config_name, shn_cfg.textfile_extensions);
 
 	xmms_cfg_write_file(cfg, filename);
 	xmms_cfg_free(cfg);
@@ -145,7 +178,7 @@ void shn_configurewin_ok(void)
 	gtk_widget_destroy(shn_configurewin);
 }
 
-void display_shn_configure(void)
+void shn_display_configure(void)
 {
 	if (shn_configurewin != NULL)
 	{
@@ -170,6 +203,12 @@ void display_shn_configure(void)
 	options_vbox = gtk_vbox_new(FALSE, 10);
 	gtk_container_set_border_width(GTK_CONTAINER(options_vbox), 5);
 
+	seektables_vbox = gtk_vbox_new(FALSE, 10);
+	gtk_container_set_border_width(GTK_CONTAINER(seektables_vbox), 5);
+
+	miscellaneous_vbox = gtk_vbox_new(FALSE, 10);
+	gtk_container_set_border_width(GTK_CONTAINER(miscellaneous_vbox), 5);
+
 /* begin error output box */
 
 	output_frame = gtk_frame_new((gchar *)" Error display options ");
@@ -217,7 +256,7 @@ void display_shn_configure(void)
 	gtk_container_set_border_width(GTK_CONTAINER(misc_vbox), 5);
 	gtk_container_add(GTK_CONTAINER(misc_frame), misc_vbox);
 
-	swap_bytes_toggle = gtk_check_button_new_with_label((gchar *)"Swap audio bytes on output (toggle if all you hear is static)");
+	swap_bytes_toggle = gtk_check_button_new_with_label((gchar *)"Swap audio bytes (toggle if all you hear is static)");
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(swap_bytes_toggle), shn_cfg.swap_bytes);
 	gtk_box_pack_start(GTK_BOX(misc_vbox), swap_bytes_toggle, FALSE, FALSE, 0);
 	gtk_widget_show(swap_bytes_toggle);
@@ -227,6 +266,27 @@ void display_shn_configure(void)
 	gtk_box_pack_start(GTK_BOX(misc_vbox), verbose_toggle, FALSE, FALSE, 0);
 	gtk_widget_show(verbose_toggle);
 
+	textfile_toggle = gtk_check_button_new_with_label((gchar *)"Load text files in file information box");
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(textfile_toggle), shn_cfg.load_textfiles);
+	gtk_box_pack_start(GTK_BOX(misc_vbox), textfile_toggle, FALSE, FALSE, 0);
+	gtk_widget_show(textfile_toggle);
+
+	textfile_extensions_hbox = gtk_hbox_new(FALSE, 5);
+	gtk_container_set_border_width(GTK_CONTAINER(textfile_extensions_hbox), 5);
+	gtk_box_pack_start(GTK_BOX(misc_vbox), textfile_extensions_hbox, FALSE, FALSE, 0);
+
+	textfile_extensions_label = gtk_label_new((gchar *)"     Text file extensions:");
+	gtk_misc_set_alignment(GTK_MISC(textfile_extensions_label), 0, 0);
+	gtk_label_set_justify(GTK_LABEL(textfile_extensions_label), GTK_JUSTIFY_LEFT);
+	gtk_box_pack_start(GTK_BOX(textfile_extensions_hbox), textfile_extensions_label, FALSE, FALSE, 0);
+	gtk_widget_show(textfile_extensions_label);
+
+	textfile_extensions_entry = gtk_entry_new();
+	gtk_entry_set_text(GTK_ENTRY(textfile_extensions_entry), shn_cfg.textfile_extensions);
+	gtk_box_pack_start(GTK_BOX(textfile_extensions_hbox), textfile_extensions_entry, TRUE, TRUE, 0);
+	gtk_widget_show(textfile_extensions_entry);
+
+	gtk_widget_show(textfile_extensions_hbox);
 	gtk_widget_show(misc_vbox);
 	gtk_widget_show(misc_frame);
 
@@ -234,14 +294,29 @@ void display_shn_configure(void)
 
 /* begin seek table path box */
 
-	path_frame = gtk_frame_new((gchar *)" Alternate seek table file location ");
+	path_frame = gtk_frame_new((gchar *)" Alternate seek table file locations ");
 	gtk_container_set_border_width(GTK_CONTAINER(path_frame), 5);
 
 	path_vbox = gtk_vbox_new(FALSE, 5);
 	gtk_container_set_border_width(GTK_CONTAINER(path_vbox), 5);
 	gtk_container_add(GTK_CONTAINER(path_frame), path_vbox);
 
-	path_label = gtk_label_new((gchar *)"Enter an alternate directory where .skt files can be found (searched\nwhen all other options fail, see the README file for more info):");
+	relative_path_label = gtk_label_new((gchar *)"Relative seek table path:");
+	gtk_misc_set_alignment(GTK_MISC(relative_path_label), 0, 0);
+	gtk_label_set_justify(GTK_LABEL(relative_path_label), GTK_JUSTIFY_LEFT);
+	gtk_box_pack_start(GTK_BOX(path_vbox), relative_path_label, FALSE, FALSE, 0);
+	gtk_widget_show(relative_path_label);
+
+	relative_path_entry_hbox = gtk_hbox_new(FALSE, 5);
+	gtk_container_set_border_width(GTK_CONTAINER(relative_path_entry_hbox), 5);
+	gtk_box_pack_start(GTK_BOX(path_vbox), relative_path_entry_hbox, TRUE, TRUE, 0);
+
+	relative_path_entry = gtk_entry_new();
+	gtk_entry_set_text(GTK_ENTRY(relative_path_entry), shn_cfg.relative_seek_tables_path);
+	gtk_box_pack_start(GTK_BOX(relative_path_entry_hbox), relative_path_entry, TRUE, TRUE, 0);
+	gtk_widget_show(relative_path_entry);
+
+	path_label = gtk_label_new((gchar *)"\nAbsolute seek table path:");
 	gtk_misc_set_alignment(GTK_MISC(path_label), 0, 0);
 	gtk_label_set_justify(GTK_LABEL(path_label), GTK_JUSTIFY_LEFT);
 	gtk_box_pack_start(GTK_BOX(path_vbox), path_label, FALSE, FALSE, 0);
@@ -261,22 +336,25 @@ void display_shn_configure(void)
 	gtk_box_pack_start(GTK_BOX(path_entry_hbox), path_browse, FALSE, FALSE, 0);
 	gtk_widget_show(path_browse);
 
+	gtk_widget_show(relative_path_entry_hbox);
 	gtk_widget_show(path_entry_hbox);
 	gtk_widget_show(path_vbox);
 	gtk_widget_show(path_frame);
 
 /* end seek table path box */
 
-	gtk_box_pack_start(GTK_BOX(options_vbox), output_frame, FALSE, FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(options_vbox), path_frame, FALSE, FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(options_vbox), misc_frame, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(options_vbox), output_frame, TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(seektables_vbox), path_frame, TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(miscellaneous_vbox), misc_frame, TRUE, TRUE, 0);
 
-	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), options_vbox, gtk_label_new((gchar *)"Options"));
+	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), options_vbox, gtk_label_new((gchar *)"Error Display"));
+	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), seektables_vbox, gtk_label_new((gchar *)"Seek Tables"));
+	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), miscellaneous_vbox, gtk_label_new((gchar *)"Miscellaneous"));
 
 	bbox = gtk_hbutton_box_new();
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(bbox), GTK_BUTTONBOX_END);
 	gtk_button_box_set_spacing(GTK_BUTTON_BOX(bbox), 5);
-	gtk_box_pack_start(GTK_BOX(vbox), bbox, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), bbox, TRUE, TRUE, 0);
 
 	ok = gtk_button_new_with_label((gchar *)"OK");
 	gtk_signal_connect(GTK_OBJECT(ok), "clicked", GTK_SIGNAL_FUNC(shn_configurewin_ok), NULL);
@@ -299,12 +377,14 @@ void display_shn_configure(void)
 
 	gtk_widget_show(bbox);
 	gtk_widget_show(options_vbox);
+	gtk_widget_show(seektables_vbox);
+	gtk_widget_show(miscellaneous_vbox);
 	gtk_widget_show(notebook);
 	gtk_widget_show(vbox);
 	gtk_widget_show(shn_configurewin);
 }
 
-void message_box(char *message)
+void shn_message_box(char *message)
 {
 	GtkWidget *mbox_win,
 		  *mbox_vbox1,
@@ -356,7 +436,147 @@ void message_box(char *message)
 	gtk_widget_show(mbox_win);
 }
 
-void display_shn_info(shn_file *tmp_file)
+void load_shntextfile(char *filename,int num,GtkWidget *shntxt_notebook)
+{
+	FILE *f;
+	char buffer[1024],*shortfilename;
+	int nchars;
+	GtkWidget *shntxt_frame,
+		  *shntxt_vbox,
+		  *shntxt_text,
+		  *shntxt_table,
+		  *shntxt_vscrollbar;
+
+	shn_debug("Loading text file '%s'",filename);
+
+	if ((shortfilename = strrchr(filename,'/')))
+		shortfilename++;
+	else
+		shortfilename = filename;
+
+	shntxt_vbox = gtk_vbox_new(FALSE, 10);
+
+	shn_snprintf(buffer,1024," %s ",shortfilename);
+
+	shntxt_frame = gtk_frame_new((gchar *)buffer);
+	gtk_container_set_border_width(GTK_CONTAINER(shntxt_frame), 10);
+	gtk_box_pack_start(GTK_BOX(shntxt_vbox), shntxt_frame, TRUE, TRUE, 0);
+
+	shntxt_text = gtk_text_new(NULL,NULL);
+
+	shntxt_table = gtk_table_new(2,2,FALSE);
+	gtk_container_add(GTK_CONTAINER(shntxt_frame), shntxt_table);
+
+	shntxt_vscrollbar = gtk_vscrollbar_new(GTK_TEXT(shntxt_text)->vadj);
+
+	gtk_text_set_editable(GTK_TEXT(shntxt_text),FALSE);
+	gtk_text_set_word_wrap(GTK_TEXT(shntxt_text),TRUE);
+
+	gtk_table_attach(GTK_TABLE(shntxt_table),shntxt_text, 0, 1, 0, 1, GTK_EXPAND | GTK_SHRINK | GTK_FILL, GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0, 0);
+	gtk_table_attach(GTK_TABLE(shntxt_table),shntxt_vscrollbar, 1, 2, 0, 1, GTK_FILL, GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0);
+
+	gtk_widget_show(shntxt_vscrollbar);
+	gtk_widget_show(shntxt_text);
+	gtk_widget_show(shntxt_table);
+	gtk_widget_show(shntxt_frame);
+	gtk_widget_show(shntxt_vbox);
+
+	if ((f = fopen(filename,"r")))
+	{
+		nchars = fread(buffer,1,1024,f);
+		while (nchars > 0)
+		{
+			gtk_text_insert(GTK_TEXT(shntxt_text),NULL,NULL,NULL,buffer,nchars);
+			nchars = fread(buffer,1,1024,f);
+		}
+		fclose(f);
+	}
+	else
+	{
+		shn_snprintf(buffer,1024,"error loading file: '%s'",filename);
+		gtk_text_insert(GTK_TEXT(shntxt_text),NULL,NULL,NULL,buffer,strlen(buffer));
+	}
+
+	shn_snprintf(buffer,1024,"Text file %d",num);
+
+	gtk_notebook_append_page(GTK_NOTEBOOK(shntxt_notebook), shntxt_vbox, gtk_label_new((gchar *)buffer));
+}
+
+void scan_for_textfiles(GtkWidget *this_notebook,char *dirname,int *filenum)
+{
+	char *ext,*textfile_exts,buffer[2048];
+	gchar *exts;
+	DIR *dp;
+	struct dirent *entry;
+
+	shn_debug("Searching for text files in directory '%s'",dirname);
+
+	if (NULL == (dp = opendir(dirname)))
+	{
+		shn_debug("Could not open directory '%s'",dirname);
+		return;
+	}
+
+	while ((entry = readdir(dp)))
+	{
+		exts = g_strdup(shn_cfg.textfile_extensions);
+
+		if ((ext = strrchr(entry->d_name,'.')))
+			ext++;
+		else
+			ext = "";
+
+		textfile_exts = strtok(exts,",");
+		while (textfile_exts)
+		{
+			if ((0 == strcmp(textfile_exts,ext)) || (0 == strcmp(textfile_exts,"")))
+			{
+				shn_snprintf(buffer,2048,"%s/%s",dirname,entry->d_name);
+
+				load_shntextfile(buffer,*filenum,this_notebook);
+				*filenum = *filenum + 1;
+				break;
+			}
+
+			textfile_exts = strtok(NULL,",");
+		}
+		
+		g_free(exts);
+	}
+
+	closedir(dp);
+}
+
+void load_shntextfiles(GtkWidget *this_notebook,char *filename)
+{
+#ifdef XMMS_SHN_LOAD_TEXTFILES
+	char *basedir,*uponedir;
+	int filenum = 1;
+
+	basedir = shn_get_base_directory(filename);
+
+	if (NULL == (uponedir = malloc((strlen(basedir) + 5) * sizeof(char))))
+	{
+		shn_debug("Could not allocate memory for search directories");
+		return;
+	}
+
+	shn_snprintf(uponedir,strlen(basedir) + 4,"%s/..",basedir);
+
+	scan_for_textfiles(this_notebook,basedir,&filenum);
+	scan_for_textfiles(this_notebook,uponedir,&filenum);
+
+	free(basedir);
+	free(uponedir);
+#else
+	shn_debug("Text file support is disabled on your platform because the\n"
+	      "appropriate functions were not found.  Please email me with\n"
+	      "the specifics of your platform, and I will try to support it.");
+#endif
+}
+
+
+void shn_display_info(shn_file *tmp_file)
 {
 	char props[BUF_SIZE];
 	char details[BUF_SIZE];
@@ -378,35 +598,21 @@ void display_shn_info(shn_file *tmp_file)
 		  *info_bbox,
 		  *info_ok;
 
-#ifdef HAVE_SNPRINTF
-	snprintf(props_label,BUF_SIZE-1,
-#else
-	sprintf(props_label,
-#endif
-		" Properties for %s ",
+	shn_snprintf(props_label,BUF_SIZE," Properties for %s ",
 		strrchr(tmp_file->wave_header.filename,'/') ?
 		strrchr(tmp_file->wave_header.filename,'/') + 1 :
 		tmp_file->wave_header.filename);
 
-#ifdef HAVE_SNPRINTF
-	snprintf(details_label,BUF_SIZE-1,
-#else
-	sprintf(details_label,
-#endif
-		" Details for %s ",
+	shn_snprintf(details_label,BUF_SIZE," Details for %s ",
 		strrchr(tmp_file->wave_header.filename,'/') ?
 		strrchr(tmp_file->wave_header.filename,'/') + 1 :
 		tmp_file->wave_header.filename);
 
-#ifdef HAVE_SNPRINTF
-	snprintf(props,BUF_SIZE-1,
-#else
-	sprintf(props,
-#endif
-		"\n"
+	shn_snprintf(props,BUF_SIZE,
+        "\n"
 		"%s\n"
 		"%s\n"
-		"%0.2f%% of original size\n"
+		"%0.4f\n"
 		"\n"
 		"%s\n"
 		"%s\n"
@@ -417,7 +623,7 @@ void display_shn_info(shn_file *tmp_file)
 		"\n",
 		tmp_file->wave_header.m_ss,
 		(tmp_file->vars.seek_table_entries == NO_SEEK_TABLE) ? "no":"yes",
-		100.0 * ((double)tmp_file->wave_header.actual_size/(double)tmp_file->wave_header.total_size),
+		(double)tmp_file->wave_header.actual_size/(double)tmp_file->wave_header.total_size,
 		(PROB_NOT_CD(tmp_file->wave_header))?"no":"yes",
 		(PROB_NOT_CD(tmp_file->wave_header))?"n/a":((PROB_BAD_BOUND(tmp_file->wave_header))?"no":"yes"),
 		(PROB_NOT_CD(tmp_file->wave_header))?"n/a":((PROB_TOO_SHORT(tmp_file->wave_header))?"no":"yes"),
@@ -425,11 +631,7 @@ void display_shn_info(shn_file *tmp_file)
 		(PROB_EXTRA_CHUNKS(tmp_file->wave_header))?"yes":"no"
 		);
 
-#ifdef HAVE_SNPRINTF
-	snprintf(details,BUF_SIZE-1,
-#else
-	sprintf(details,
-#endif
+	shn_snprintf(details,BUF_SIZE,
 		"0x%04x (%s)\n"
 		"%hu\n"
 		"%hu\n"
@@ -443,7 +645,7 @@ void display_shn_info(shn_file *tmp_file)
 		"%lu bytes\n"
 		"%lu bytes",
 		tmp_file->wave_header.wave_format,
-		format_to_str(tmp_file->wave_header.wave_format),
+		shn_format_to_str(tmp_file->wave_header.wave_format),
 		tmp_file->wave_header.channels,
 		tmp_file->wave_header.bits_per_sample,
 		tmp_file->wave_header.samples_per_sec,
@@ -457,8 +659,6 @@ void display_shn_info(shn_file *tmp_file)
 		tmp_file->wave_header.actual_size
 		);
 
-	unload_shn(tmp_file);
-
 	info_win = gtk_window_new(GTK_WINDOW_DIALOG);
 	gtk_signal_connect(GTK_OBJECT(info_win), "destroy", GTK_SIGNAL_FUNC(gtk_widget_destroyed), &info_win);
 	gtk_window_set_title(GTK_WINDOW(info_win), (gchar *)"Shorten file information");
@@ -477,7 +677,7 @@ void display_shn_info(shn_file *tmp_file)
 
 	props_frame = gtk_frame_new((gchar *)props_label);
 	gtk_container_set_border_width(GTK_CONTAINER(props_frame), 10);
-	gtk_box_pack_start(GTK_BOX(props_vbox), props_frame, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(props_vbox), props_frame, TRUE, TRUE, 0);
 
 	props_hbox = gtk_hbox_new(FALSE, 10);
 	gtk_container_set_border_width(GTK_CONTAINER(props_hbox), 5);
@@ -518,7 +718,7 @@ void display_shn_info(shn_file *tmp_file)
 
 	details_frame = gtk_frame_new((gchar *)details_label);
 	gtk_container_set_border_width(GTK_CONTAINER(details_frame), 10);
-	gtk_box_pack_start(GTK_BOX(details_vbox), details_frame, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(details_vbox), details_frame, TRUE, TRUE, 0);
 
 	details_hbox = gtk_hbox_new(FALSE, 10);
 	gtk_container_set_border_width(GTK_CONTAINER(details_hbox), 5);
@@ -574,6 +774,16 @@ void display_shn_info(shn_file *tmp_file)
 	gtk_widget_show(details_frame);
 	gtk_widget_show(details_hbox);
 	gtk_widget_show(details_vbox);
+
+/* begin any text files pages */
+
+	if (shn_cfg.load_textfiles)
+		load_shntextfiles(info_notebook,tmp_file->wave_header.filename);
+
+/* end any text files pages */
+
+	gtk_notebook_set_page(GTK_NOTEBOOK(info_notebook), 0);
+
 	gtk_widget_show(info_notebook);
 	gtk_widget_show(main_vbox);
 	gtk_widget_show(info_bbox);
