@@ -1,5 +1,5 @@
 /*  misc.c - miscellaneous functions
- *  Copyright (C) 2000-2001  Jason Jordan (shnutils@freeshell.org)
+ *  Copyright (C) 2000-2003  Jason Jordan <shnutils@freeshell.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,14 +17,28 @@
  */
 
 /*
- * $Id: misc.c,v 1.5 2001/12/30 05:12:04 jason Exp $
+ * $Id: misc.c,v 1.11 2003/08/26 05:34:04 jason Exp $
  */
 
 #include <stdlib.h>
 #include <string.h>
 #include "shorten.h"
 
-int filename_contains_a_dot(char *filename)
+void shn_snprintf(char *dest,int maxlen,char *formatstr, ...)
+/* acts like snprintf, but makes 100% sure the string is NULL-terminated */
+{
+  va_list args;
+
+  va_start(args,formatstr);
+
+  shn_vsnprintf(dest,maxlen,formatstr,args);
+
+  dest[maxlen-1] = 0;
+
+  va_end(args);
+}
+
+int shn_filename_contains_a_dot(char *filename)
 {
 	char *slash,*dot;
 
@@ -42,7 +56,60 @@ int filename_contains_a_dot(char *filename)
 		return 0;
 }
 
-void length_to_str(shn_file *info)
+char *shn_get_base_filename(char *filename)
+{
+	char *b,*e,*p,*base;
+
+	b = strrchr(filename,'/');
+
+	if (b)
+		b++;
+	else
+		b = filename;
+
+	e = strrchr(filename,'.');
+
+	if (e < b)
+		e = filename + strlen(filename);
+
+	if (NULL == (base = malloc((e - b + 1) * sizeof(char))))
+	{
+		shn_debug("Could not allocate memory for base filename");
+		return NULL;
+	}
+
+	for (p=b;p<e;p++)
+		*(base + (p - b)) = *p;
+
+	*(base + (p - b)) = '\0';
+
+	return base;
+}
+
+char *shn_get_base_directory(char *filename)
+{
+	char *e,*p,*base;
+
+	e = strrchr(filename,'/');
+
+	if (!e)
+		e = filename;
+
+	if (NULL == (base = malloc((e - filename + 1) * sizeof(char))))
+	{
+		shn_debug("Could not allocate memory for base directory");
+		return NULL;
+	}
+
+	for (p=filename;p<e;p++)
+		*(base + (p - filename)) = *p;
+
+	*(base + (p - filename)) = '\0';
+
+	return base;
+}
+
+void shn_length_to_str(shn_file *info)
 {
 	ulong newlength,rem1,rem2,frames;
 
