@@ -1,5 +1,5 @@
 /*  output.c - functions for message and error output
- *  Copyright (C) 2000-2001  Jason Jordan (shnutils@freeshell.org)
+ *  Copyright (C) 2000-2003  Jason Jordan <shnutils@freeshell.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  */
 
 /*
- * $Id: output.c,v 1.4 2001/12/30 05:12:04 jason Exp $
+ * $Id: output.c,v 1.9 2003/08/26 05:34:04 jason Exp $
  */
 
 #include <stdio.h>
@@ -44,25 +44,21 @@ void print_lines(char *prefix,char *message)
   fprintf(stderr,"%s%s\n",prefix,tail);
 }
 
-void error(char *msg, ...)
+void shn_error(char *msg, ...)
 {
   va_list args;
   char msgbuf[BUF_SIZE];
 
   va_start(args,msg);
 
-#ifdef HAVE_VSNPRINTF
-  vsnprintf(msgbuf,BUF_SIZE-1,msg,args);
-#else
-  vsprintf(msgbuf,msg,args);
-#endif
+  shn_vsnprintf(msgbuf,BUF_SIZE,msg,args);
 
   switch (shn_cfg.error_output_method) {
     case ERROR_OUTPUT_STDERR:
-      print_lines(PACKAGE ":  ",msgbuf);
+      print_lines(PACKAGE ": ",msgbuf);
       break;
     case ERROR_OUTPUT_WINDOW:
-      message_box(msgbuf);
+      shn_message_box(msgbuf);
       break;
     default:
       if (0 != shn_cfg.verbose)
@@ -72,18 +68,14 @@ void error(char *msg, ...)
   va_end(args);
 }
 
-void debug(char *msg, ...)
+void shn_debug(char *msg, ...)
 {
   va_list args;
   char msgbuf[BUF_SIZE];
 
   va_start(args,msg);
 
-#ifdef HAVE_VSNPRINTF
-  vsnprintf(msgbuf,BUF_SIZE-1,msg,args);
-#else
-  vsprintf(msgbuf,msg,args);
-#endif
+  shn_vsnprintf(msgbuf,BUF_SIZE,msg,args);
 
   if (0 != shn_cfg.verbose)
     print_lines(PACKAGE " [debug]: ",msgbuf);
@@ -91,7 +83,7 @@ void debug(char *msg, ...)
   va_end(args);
 }
 
-void fatal_error(shn_file *this_shn,char *complaint, ...)
+void shn_error_fatal(shn_file *this_shn,char *complaint, ...)
 {
   va_list args;
 
@@ -101,11 +93,7 @@ void fatal_error(shn_file *this_shn,char *complaint, ...)
     if (0 == this_shn->vars.fatal_error) {
       this_shn->vars.fatal_error = 1;
       this_shn->vars.going = 0;
-#ifdef HAVE_VSNPRINTF
-      vsnprintf(this_shn->vars.fatal_error_msg,BUF_SIZE-1,complaint,args);
-#else
-      vsprintf(this_shn->vars.fatal_error_msg,complaint,args);
-#endif
+      shn_vsnprintf(this_shn->vars.fatal_error_msg,BUF_SIZE,complaint,args);
     }
   }
 
