@@ -1,5 +1,5 @@
 /*  shn.c - main functions for xmms-shn
- *  Copyright (C) 2000-2001  Jason Jordan (shnutils@freeshell.org)
+ *  Copyright (C) 2000-2003  Jason Jordan <shnutils@freeshell.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  */
 
 /*
- * $Id: shn.c,v 1.9 2001/12/30 05:12:04 jason Exp $
+ * $Id: shn.c,v 1.23 2003/08/26 05:34:04 jason Exp $
  */
 
 #include <stdio.h>
@@ -35,14 +35,14 @@
 static void shn_about(void);
 static void shn_configure(void);
 static void shn_init(void);
-static int is_our_file(char *filename);
-static void play_file(char *filename);
+static int  shn_is_our_file(char *);
+static void shn_play(char *);
 static void shn_stop(void);
-static void shn_seek(int time);
-static void shn_pause(short p);
-static int get_time(void);
-static void get_song_info(char *filename, char **title, int *length);
-static void show_shn_info(char *filename);
+static void shn_seek(int);
+static void shn_pause(short);
+static int  shn_get_time(void);
+static void shn_get_file_info(char *,char **,int *);
+static void shn_display_file_info(char *);
 
 InputPlugin shn_ip =
 {
@@ -52,14 +52,14 @@ InputPlugin shn_ip =
 	shn_init,
 	shn_about,
 	shn_configure,
-	is_our_file,
+	shn_is_our_file,
 	NULL,
-	play_file,
+	shn_play,
 	shn_stop,
 	shn_pause,
 	shn_seek,
 	NULL,
-	get_time,
+	shn_get_time,
 	NULL,
 	NULL,
 	NULL,
@@ -67,8 +67,8 @@ InputPlugin shn_ip =
 	NULL,
 	NULL,
 	NULL,
-	get_song_info,
-	show_shn_info,
+	shn_get_file_info,
+	shn_display_file_info,
 	NULL
 };
 
@@ -87,10 +87,16 @@ static void shn_init()
 	shn_cfg.error_output_method_config_name = "error_output_method";
 	shn_cfg.seek_tables_path = NULL;
 	shn_cfg.seek_tables_path_config_name = "seek_tables_path";
+	shn_cfg.relative_seek_tables_path = NULL;
+	shn_cfg.relative_seek_tables_path_config_name = "relative_seek_tables_path";
 	shn_cfg.verbose = 0;
 	shn_cfg.verbose_config_name = "verbose";
 	shn_cfg.swap_bytes = 0;
 	shn_cfg.swap_bytes_config_name = "swap_bytes";
+	shn_cfg.load_textfiles = FALSE;
+	shn_cfg.load_textfiles_config_name = "load_textfiles";
+	shn_cfg.textfile_extensions = NULL;
+	shn_cfg.textfile_extensions_config_name = "textfile_extensions";
 
 	filename = g_strconcat(g_get_home_dir(), "/.xmms/config", NULL);
 	if ((cfg = xmms_cfg_open_file(filename)) != 0)
@@ -99,7 +105,12 @@ static void shn_init()
 		xmms_cfg_read_boolean(cfg, XMMS_SHN_VERSION_TAG, shn_cfg.verbose_config_name, &shn_cfg.verbose);
 		if (!xmms_cfg_read_string(cfg, XMMS_SHN_VERSION_TAG, shn_cfg.seek_tables_path_config_name, &shn_cfg.seek_tables_path))
 			shn_cfg.seek_tables_path = g_strdup(g_get_home_dir());
+		if (!xmms_cfg_read_string(cfg, XMMS_SHN_VERSION_TAG, shn_cfg.relative_seek_tables_path_config_name, &shn_cfg.relative_seek_tables_path))
+			shn_cfg.relative_seek_tables_path = g_strdup("");
 		xmms_cfg_read_boolean(cfg, XMMS_SHN_VERSION_TAG, shn_cfg.swap_bytes_config_name, &shn_cfg.swap_bytes);
+		xmms_cfg_read_boolean(cfg, XMMS_SHN_VERSION_TAG, shn_cfg.load_textfiles_config_name, &shn_cfg.load_textfiles);
+		if (!xmms_cfg_read_string(cfg, XMMS_SHN_VERSION_TAG, shn_cfg.textfile_extensions_config_name, &shn_cfg.textfile_extensions))
+			shn_cfg.textfile_extensions = g_strdup("txt,nfo");
 		xmms_cfg_free(cfg);
 	}
 
@@ -113,12 +124,12 @@ InputPlugin *get_iplugin_info(void)
 
 static void shn_about()
 {
-	display_shn_about();
+	shn_display_about();
 }
 
 static void shn_configure()
 {
-	display_shn_configure();
+	shn_display_configure();
 }
 
 int init_decode_state(shn_file *this_shn)
@@ -149,7 +160,7 @@ int init_decode_state(shn_file *this_shn)
 
 	if (!(this_shn->decode_state = malloc(sizeof(shn_decode_state))))
 	{
-		debug("Could not allocate memory for decode state data structure");
+		shn_debug("Could not allocate memory for decode state data structure");
 		return 0;
 	}
 
@@ -329,7 +340,7 @@ int get_wave_header(shn_file *this_shn)
 
             while (cklen--) {
               if (this_shn->vars.bytes_in_header >= OUT_BUFFER_SIZE) {
-                  debug("Unexpectedly large header - " PACKAGE " can only handle a maximum of %d bytes",OUT_BUFFER_SIZE);
+                  shn_debug("Unexpectedly large header - " PACKAGE " can only handle a maximum of %d bytes",OUT_BUFFER_SIZE);
                   retval = 0;
                   goto got_enough_data;
               }
@@ -359,7 +370,7 @@ got_enough_data:
     return retval;
 }
 
-void unload_shn(shn_file *this_shn)
+void shn_unload(shn_file *this_shn)
 {
 	int this_shn_is_shnfile = (this_shn == shnfile) ? 1 : 0;
 
@@ -412,11 +423,11 @@ shn_file *load_shn(char *filename)
 {
 	shn_file *tmp_file;
 
-	debug("Loading file: '%s'",filename);
+	shn_debug("Loading file: '%s'",filename);
 
 	if (!(tmp_file = malloc(sizeof(shn_file))))
 	{
-		debug("Could not allocate memory for SHN data structure");
+		shn_debug("Could not allocate memory for SHN data structure");
 		return NULL;
 	}
 
@@ -452,23 +463,23 @@ shn_file *load_shn(char *filename)
 
 	if (!(tmp_file->vars.fd = fopen(filename,"r")))
 	{
-		debug("Could not open file: '%s'",filename);
-		unload_shn(tmp_file);
+		shn_debug("Could not open file: '%s'",filename);
+		shn_unload(tmp_file);
 		return NULL;
 	}
 
 	if (0 == get_wave_header(tmp_file))
 	{
-		debug("Unable to read WAVE header from file '%s'",filename);
-		unload_shn(tmp_file);
+		shn_debug("Unable to read WAVE header from file '%s'",filename);
+		shn_unload(tmp_file);
 		return NULL;
 	}
 
 	fseek(tmp_file->vars.fd,0,SEEK_SET);
-	if (0 == verify_header(tmp_file))
+	if (0 == shn_verify_header(tmp_file))
 	{
-		debug("Invalid WAVE header in file: '%s'",filename);
-		unload_shn(tmp_file);
+		shn_debug("Invalid WAVE header in file: '%s'",filename);
+		shn_unload(tmp_file);
 		return NULL;
 	}
 
@@ -478,14 +489,14 @@ shn_file *load_shn(char *filename)
 		tmp_file->decode_state = NULL;
 	}
 
-	load_seek_table(tmp_file,filename);
+	shn_load_seek_table(tmp_file,filename);
 
-	debug("Successfully loaded file: '%s'",filename);
+	shn_debug("Successfully loaded file: '%s'",filename);
 
 	return tmp_file;
 }
 
-static int is_our_file(char *filename)
+static int shn_is_our_file(char *filename)
 {
 	shn_file *tmp_file;
 	FILE *f;
@@ -507,7 +518,7 @@ static int is_our_file(char *filename)
 	if (!(tmp_file = load_shn(filename)))
 		return FALSE;
 
-	unload_shn(tmp_file);
+	shn_unload(tmp_file);
 	tmp_file = NULL;
 	return TRUE;
 }
@@ -526,17 +537,20 @@ void swap_bytes(shn_file *this_shn,int bytes)
 
 void write_and_wait(shn_file *this_shn,int block_size)
 {
-	int bytes_to_write,i,x;
-        uchar temp;
+	int bytes_to_write,bytes_in_block,i;
 
 	if (this_shn->vars.bytes_in_buf < block_size)
 		return;
 
-	bytes_to_write = min(this_shn->vars.bytes_in_buf, block_size);
+	bytes_in_block = min(this_shn->vars.bytes_in_buf, block_size);
 
-	if (bytes_to_write <= 0)
+	if (bytes_in_block <= 0)
 		return;
 
+	bytes_to_write = bytes_in_block;
+	while ((bytes_to_write + bytes_in_block) <= this_shn->vars.bytes_in_buf)
+		bytes_to_write += bytes_in_block;
+
 	shn_ip.add_vis_pcm(shn_ip.output->written_time(), (this_shn->wave_header.bits_per_sample == 16) ? FMT_S16_LE : FMT_U8,
 		this_shn->wave_header.channels, bytes_to_write, this_shn->vars.buffer);
 
@@ -593,7 +607,7 @@ restart:
     {
       for(i = 0; i < strlen(magic); i++)
 	if(getc_exit(this_shn->vars.fd) != magic[i]) {
-	  fatal_error(this_shn,"Bad magic number");
+	  shn_error_fatal(this_shn,"Bad magic number");
           goto exit_thread;
         }
 
@@ -610,7 +624,7 @@ restart:
       {
   	int byte = getc(this_shn->vars.fd);
 	if(byte == EOF) {
-	  fatal_error(this_shn,"No magic number");
+	  shn_error_fatal(this_shn,"No magic number");
           goto exit_thread;
         }
 	if(magic[nscan] != '\0' && byte == magic[nscan])
@@ -633,7 +647,7 @@ restart:
 
     /* check version number */
     if(version > MAX_SUPPORTED_VERSION) {
-      fatal_error(this_shn,"Can't decode version %d", version);
+      shn_error_fatal(this_shn,"Can't decode version %d", version);
       goto exit_thread;
     }
 
@@ -658,7 +672,7 @@ restart:
       else             /* check that the requested conversion is valid */
 	if(internal_ftype == TYPE_AU1 || internal_ftype == TYPE_AU2 ||
 	   internal_ftype == TYPE_AU3 || ftype == TYPE_AU1 ||ftype == TYPE_AU2 || ftype == TYPE_AU3) {
-	  fatal_error(this_shn,"Not able to perform requested output format conversion");
+	  shn_error_fatal(this_shn,"Not able to perform requested output format conversion");
           goto cleanup;
         }
     }
@@ -862,35 +876,37 @@ restart:
 
               if (this_shn->vars.seek_to != -1)
               {
-                shn_seek_entry *seek_info = seek_entry_search(this_shn->seek_table,this_shn->vars.seek_to * (ulong)this_shn->wave_header.samples_per_sec,0,
-							      (ulong)(this_shn->vars.seek_table_entries - 1));
+                shn_seek_entry *seek_info;
 
-                debug("Seeking to %d:%02d",this_shn->vars.seek_to/60,this_shn->vars.seek_to%60);
+                shn_debug("Seeking to %d:%02d",this_shn->vars.seek_to/60,this_shn->vars.seek_to%60);
 
-                buffer[0][-1] = uchar_to_slong_le(seek_info->data+24);
-                buffer[0][-2] = uchar_to_slong_le(seek_info->data+28);
-                buffer[0][-3] = uchar_to_slong_le(seek_info->data+32);
-                offset[0][0]  = uchar_to_slong_le(seek_info->data+48);
-                offset[0][1]  = uchar_to_slong_le(seek_info->data+52);
-                offset[0][2]  = uchar_to_slong_le(seek_info->data+56);
-                offset[0][3]  = uchar_to_slong_le(seek_info->data+60);
+                seek_info = shn_seek_entry_search(this_shn->seek_table,this_shn->vars.seek_to * (ulong)this_shn->wave_header.samples_per_sec,0,
+							      (ulong)(this_shn->vars.seek_table_entries - 1),this_shn->vars.seek_resolution);
+
+                buffer[0][-1] = shn_uchar_to_slong_le(seek_info->data+24);
+                buffer[0][-2] = shn_uchar_to_slong_le(seek_info->data+28);
+                buffer[0][-3] = shn_uchar_to_slong_le(seek_info->data+32);
+                offset[0][0]  = shn_uchar_to_slong_le(seek_info->data+48);
+                offset[0][1]  = shn_uchar_to_slong_le(seek_info->data+52);
+                offset[0][2]  = shn_uchar_to_slong_le(seek_info->data+56);
+                offset[0][3]  = shn_uchar_to_slong_le(seek_info->data+60);
 		if (nchan > 1)
 		{
-	                buffer[1][-1] = uchar_to_slong_le(seek_info->data+36);
-        	        buffer[1][-2] = uchar_to_slong_le(seek_info->data+40);
-                	buffer[1][-3] = uchar_to_slong_le(seek_info->data+44);
-	                offset[1][0]  = uchar_to_slong_le(seek_info->data+64);
-        	        offset[1][1]  = uchar_to_slong_le(seek_info->data+68);
-                	offset[1][2]  = uchar_to_slong_le(seek_info->data+72);
-	                offset[1][3]  = uchar_to_slong_le(seek_info->data+76);
+	                buffer[1][-1] = shn_uchar_to_slong_le(seek_info->data+36);
+        	        buffer[1][-2] = shn_uchar_to_slong_le(seek_info->data+40);
+                	buffer[1][-3] = shn_uchar_to_slong_le(seek_info->data+44);
+	                offset[1][0]  = shn_uchar_to_slong_le(seek_info->data+64);
+        	        offset[1][1]  = shn_uchar_to_slong_le(seek_info->data+68);
+                	offset[1][2]  = shn_uchar_to_slong_le(seek_info->data+72);
+	                offset[1][3]  = shn_uchar_to_slong_le(seek_info->data+76);
 		}
-                bitshift = uchar_to_ushort_le(seek_info->data+22);
-                fseek(this_shn->vars.fd,(slong)uchar_to_ulong_le(seek_info->data+8),SEEK_SET);
+                bitshift = shn_uchar_to_ushort_le(seek_info->data+22);
+                fseek(this_shn->vars.fd,(slong)shn_uchar_to_ulong_le(seek_info->data+8),SEEK_SET);
                 fread((uchar*) this_shn->decode_state->getbuf, 1, BUFSIZ, this_shn->vars.fd);
-                this_shn->decode_state->getbufp = this_shn->decode_state->getbuf + uchar_to_ushort_le(seek_info->data+14);
-                this_shn->decode_state->nbitget = uchar_to_ushort_le(seek_info->data+16);
-                this_shn->decode_state->nbyteget = uchar_to_ushort_le(seek_info->data+12);
-                this_shn->decode_state->gbuffer = uchar_to_ulong_le(seek_info->data+18);
+                this_shn->decode_state->getbufp = this_shn->decode_state->getbuf + shn_uchar_to_ushort_le(seek_info->data+14);
+                this_shn->decode_state->nbitget = shn_uchar_to_ushort_le(seek_info->data+16);
+                this_shn->decode_state->nbyteget = shn_uchar_to_ushort_le(seek_info->data+12);
+                this_shn->decode_state->gbuffer = shn_uchar_to_ulong_le(seek_info->data+18);
 
                 this_shn->vars.bytes_in_buf = 0;
 
@@ -959,7 +975,7 @@ restart:
             break;
 
           default:
-            fatal_error(this_shn,"Sanity check fails trying to decode function: %d",cmd);
+            shn_error_fatal(this_shn,"Sanity check fails trying to decode function: %d",cmd);
             goto cleanup;
         }
     }
@@ -990,7 +1006,7 @@ exit_thread:
     pthread_exit(NULL);
 }
 
-static void play_file(char *filename)
+static void shn_play(char *filename)
 {
 	char *name, *temp;
 
@@ -998,7 +1014,7 @@ static void play_file(char *filename)
 
 	if (!(shnfile = load_shn(filename)))
 	{
-		debug("Could not load file for playing:\n'%s'",filename);
+		shn_debug("Could not load file for playing: '%s'",filename);
 		return;
 	}
 
@@ -1009,7 +1025,7 @@ static void play_file(char *filename)
 	if (shn_ip.output->open_audio((shnfile->wave_header.bits_per_sample == 16) ? FMT_S16_LE : FMT_U8, shnfile->wave_header.samples_per_sec, shnfile->wave_header.channels) == 0)
 	{
 		audio_error = TRUE;
-		debug("Could not open audio device for playback (check your output plugin configuration)");
+		shn_debug("Could not open audio device for playback (check your output plugin configuration)");
 		return;
 	}
 	temp = strrchr(filename, '/');
@@ -1019,7 +1035,7 @@ static void play_file(char *filename)
 		temp++;
 	name = malloc(strlen(temp) + 1);
 	strcpy(name, temp);
-	if (filename_contains_a_dot(name))
+	if (shn_filename_contains_a_dot(name))
 		*(strrchr(name,'.')) = '\0';
 	shn_ip.set_info(name, 1000 * shnfile->wave_header.length, 8 * shnfile->wave_header.rate, shnfile->wave_header.samples_per_sec, shnfile->wave_header.channels);
 	free(name);
@@ -1036,23 +1052,18 @@ static void shn_stop(void)
 		return;
 
 	if ((was_fatal = shnfile->vars.fatal_error))
-#ifdef HAVE_SNPRINTF
-		snprintf(error_msg,BUF_SIZE-1,
-#else
-		sprintf(error_msg,
-#endif
-			"%s.\nAffected file was:\n%s",shnfile->vars.fatal_error_msg,shnfile->wave_header.filename);
+		shn_snprintf(error_msg,BUF_SIZE,"%s.\nAffected file was:\n%s",shnfile->vars.fatal_error_msg,shnfile->wave_header.filename);
 
 	if (shnfile->vars.going || was_fatal)
 	{
 		shnfile->vars.going = 0;
 		pthread_join(decode_thread, NULL);
 		shn_ip.output->close_audio();
-		unload_shn(shnfile);
+		shn_unload(shnfile);
 	}
 
 	if (was_fatal)
-		error(error_msg);
+		shn_error(error_msg);
 }
 
 static void shn_pause(short p)
@@ -1062,13 +1073,13 @@ static void shn_pause(short p)
 
 static void shn_seek(int time)
 {
-	if (NULL != shnfile)
+	if (NULL == shnfile)
+		return;
+
+	if (shnfile->vars.seek_table_entries == NO_SEEK_TABLE)
 	{
-		if (shnfile->vars.seek_table_entries == NO_SEEK_TABLE)
-		{
-			error("Cannot seek to %d:%02d because there is\nno seek information for this file.",time/60,time%60);
-			return;
-		}
+		shn_error("Cannot seek to %d:%02d because there is no seek information for this file.",time/60,time%60);
+		return;
 	}
 
 	shnfile->vars.seek_to = time;
@@ -1079,7 +1090,7 @@ static void shn_seek(int time)
 		xmms_usleep(10000);
 }
 
-static int get_time(void)
+static int shn_get_time(void)
 {
 	if (audio_error)
 		return -2;
@@ -1090,7 +1101,7 @@ static int get_time(void)
 	return shn_ip.output->output_time();
 }
 
-static void get_song_info(char *filename, char **title, int *length)
+static void shn_get_file_info(char *filename, char **title, int *length)
 {
 	char *name, *temp;
 	shn_file *tmp_file;
@@ -1102,7 +1113,7 @@ static void get_song_info(char *filename, char **title, int *length)
 		temp++;
 	name = g_malloc(strlen(temp) + 1);
 	strcpy(name, temp);
-	if (filename_contains_a_dot(name))
+	if (shn_filename_contains_a_dot(name))
 		*(strrchr(name,'.')) = '\0';
 	(*title) = name;
 
@@ -1110,24 +1121,26 @@ static void get_song_info(char *filename, char **title, int *length)
 
 	if (!(tmp_file = load_shn(filename)))
 	{
-		debug("Could not get information from file: '%s'",filename);
+		shn_debug("Could not get information from file: '%s'",filename);
 		return;
 	}
 
 	(*length) = 1000 * tmp_file->wave_header.length;
 
-	unload_shn(tmp_file);
+	shn_unload(tmp_file);
 }
 
-static void show_shn_info(char *filename)
+static void shn_display_file_info(char *filename)
 {
 	shn_file *tmp_file;
 
 	if (!(tmp_file = load_shn(filename)))
 	{
-		debug("Could not get information from file: '%s'",filename);
+		shn_debug("Could not get information from file: '%s'",filename);
 		return;
 	}
 
-	display_shn_info(tmp_file);
+	shn_display_info(tmp_file);
+
+	shn_unload(tmp_file);
 }
