@@ -7,7 +7,7 @@
 ******************************************************************************/
 
 /*
- * $Id: vario.c,v 1.6 2001/12/30 05:12:04 jason Exp $
+ * $Id: vario.c,v 1.7 2003/08/26 05:34:04 jason Exp $
  */
 
 #include <math.h>
@@ -49,7 +49,7 @@ ulong word_get(shn_file *this_shn)
   {
     this_shn->decode_state->nbyteget += fread((uchar*) this_shn->decode_state->getbuf, 1, BUFSIZ, this_shn->vars.fd);
     if(this_shn->decode_state->nbyteget < 4) {
-      fatal_error(this_shn,"Premature EOF on compressed stream -\npossible corrupt or truncated file");
+      shn_error_fatal(this_shn,"Premature EOF on compressed stream -\npossible corrupt or truncated file");
       return (ulong)0;
     }
     this_shn->decode_state->getbufp = this_shn->decode_state->getbuf;
