@@ -1,5 +1,5 @@
 /*  wave.c - functions to parse and verify WAVE headers
- *  Copyright (C) 2000-2001  Jason Jordan (shnutils@freeshell.org)
+ *  Copyright (C) 2000-2003  Jason Jordan <shnutils@freeshell.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  */
 
 /*
- * $Id: wave.c,v 1.5 2001/12/30 05:12:04 jason Exp $
+ * $Id: wave.c,v 1.9 2003/08/26 05:43:39 jason Exp $
  */
 
 #include <stdlib.h>
@@ -41,38 +41,38 @@ int is_valid_file(shn_file *info)
 
   if (0 != stat(info->wave_header.filename,&sz)) {
     if (errno == ENOENT)
-      error("cannot open '%s' because it does not exist",info->wave_header.filename);
+      shn_error("cannot open '%s' because it does not exist",info->wave_header.filename);
     else if (errno == EACCES)
-      error("cannot open '%s' due to insufficient permissions",info->wave_header.filename);
+      shn_error("cannot open '%s' due to insufficient permissions",info->wave_header.filename);
     else if (errno == EFAULT)
-      error("cannot open '%s' due to bad address",info->wave_header.filename);
+      shn_error("cannot open '%s' due to bad address",info->wave_header.filename);
     else if (errno == ENOMEM)
-      error("cannot open '%s' because the kernel ran out of memory",info->wave_header.filename);
+      shn_error("cannot open '%s' because the kernel ran out of memory",info->wave_header.filename);
     else if (errno == ENAMETOOLONG)
-      error("cannot open '%s' because the file name is too long",info->wave_header.filename);
+      shn_error("cannot open '%s' because the file name is too long",info->wave_header.filename);
     else
-      error("cannot open '%s' due to an unknown problem",info->wave_header.filename);
+      shn_error("cannot open '%s' due to an unknown problem",info->wave_header.filename);
     return 0;
   }
   if (0 == S_ISREG(sz.st_mode)) {
     if (S_ISLNK(sz.st_mode))
-      error("'%s' is a symbolic link, not a regular file",info->wave_header.filename);
+      shn_error("'%s' is a symbolic link, not a regular file",info->wave_header.filename);
     else if (S_ISDIR(sz.st_mode))
-      error("'%s' is a directory, not a regular file",info->wave_header.filename);
+      shn_error("'%s' is a directory, not a regular file",info->wave_header.filename);
     else if (S_ISCHR(sz.st_mode))
-      error("'%s' is a character device, not a regular file",info->wave_header.filename);
+      shn_error("'%s' is a character device, not a regular file",info->wave_header.filename);
     else if (S_ISBLK(sz.st_mode))
-      error("'%s' is a block device, not a regular file",info->wave_header.filename);
+      shn_error("'%s' is a block device, not a regular file",info->wave_header.filename);
     else if (S_ISFIFO(sz.st_mode))
-      error("'%s' is a fifo, not a regular file",info->wave_header.filename);
+      shn_error("'%s' is a fifo, not a regular file",info->wave_header.filename);
     else if (S_ISSOCK(sz.st_mode))
-      error("'%s' is a socket, not a regular file",info->wave_header.filename);
+      shn_error("'%s' is a socket, not a regular file",info->wave_header.filename);
     return 0;
   }
   info->wave_header.actual_size = (ulong)sz.st_size;
 
   if (NULL == (f = fopen(info->wave_header.filename,"rb"))) {
-    error("could not open '%s': %s",info->wave_header.filename,strerror(errno));
+    shn_error("could not open '%s': %s",info->wave_header.filename,strerror(errno));
     return 0;
   }
   fclose(f);
@@ -80,38 +80,36 @@ int is_valid_file(shn_file *info)
   return 1;
 }
 
-int verify_header(shn_file *this_shn)
+int shn_verify_header(shn_file *this_shn)
 {
 	ulong l;
 	int cur = 0;
 
 	if (0 == is_valid_file(this_shn))
 	{
-		debug("while processing '%s': something went wrong while opening this file, see above",this_shn->wave_header.filename);
+		shn_debug("while processing '%s': something went wrong while opening this file, see above",this_shn->wave_header.filename);
 		return 0;
 	}
 
 	if (this_shn->vars.bytes_in_header < CANONICAL_HEADER_SIZE) {
-		debug("while processing '%s': header %d bytes (less than minimum of %d bytes)",
+		shn_debug("while processing '%s': header is only %d bytes (should be at least %d bytes)",
 			this_shn->wave_header.filename,this_shn->vars.bytes_in_header,CANONICAL_HEADER_SIZE);
 		return 0;
 	}
 
-	if (WAVE_RIFF != uchar_to_ulong_le(this_shn->vars.header+cur))
+	if (WAVE_RIFF != shn_uchar_to_ulong_le(this_shn->vars.header+cur))
 	{
-		debug("Expected 'RIFF' but didn't see it");
-		debug("while processing '%s': WAVE header is missing RIFF tag - possible corrupt file",this_shn->wave_header.filename);
+		shn_debug("while processing '%s': WAVE header is missing RIFF tag - possible corrupt file",this_shn->wave_header.filename);
 		return 0;
 	}
 	cur += 4;
 
-	this_shn->wave_header.chunk_size = uchar_to_ulong_le(this_shn->vars.header+cur);
+	this_shn->wave_header.chunk_size = shn_uchar_to_ulong_le(this_shn->vars.header+cur);
 	cur += 4;
 
-	if (WAVE_WAVE != uchar_to_ulong_le(this_shn->vars.header+cur))
+	if (WAVE_WAVE != shn_uchar_to_ulong_le(this_shn->vars.header+cur))
 	{
-		debug("Expected 'WAVE' but didn't see it");
-		debug("while processing '%s': WAVE header is missing WAVE tag",this_shn->wave_header.filename);
+		shn_debug("while processing '%s': WAVE header is missing WAVE tag",this_shn->wave_header.filename);
 		return 0;
 	}
 	cur += 4;
@@ -120,10 +118,10 @@ int verify_header(shn_file *this_shn)
 	{
 		cur += 4;
 
-		l = uchar_to_ulong_le(this_shn->vars.header+cur);
+		l = shn_uchar_to_ulong_le(this_shn->vars.header+cur);
 		cur += 4;
 
-		if (WAVE_FMT == uchar_to_ulong_le(this_shn->vars.header+cur-8))
+		if (WAVE_FMT == shn_uchar_to_ulong_le(this_shn->vars.header+cur-8))
 			break;
 
 		cur += l;
@@ -131,12 +129,11 @@ int verify_header(shn_file *this_shn)
 
 	if (l < 16)
 	{
-		debug("Error parsing WAVE header: len < 16");
-		debug("while processing '%s': fmt chunk in WAVE header was too short",this_shn->wave_header.filename);
+		shn_debug("while processing '%s': fmt chunk in WAVE header was too short",this_shn->wave_header.filename);
 		return 0;
 	}
 
-	this_shn->wave_header.wave_format = uchar_to_ushort_le(this_shn->vars.header+cur);
+	this_shn->wave_header.wave_format = shn_uchar_to_ushort_le(this_shn->vars.header+cur);
 	cur += 2;
 
 	switch (this_shn->wave_header.wave_format)
@@ -144,27 +141,25 @@ int verify_header(shn_file *this_shn)
 		case WAVE_FORMAT_PCM:
 			break;
 		default:
-			debug("WAVE data is not PCM");
-			debug("while processing '%s': unsupported format 0x%04x (%s) - only PCM data is supported at this time",
-				this_shn->wave_header.filename,this_shn->wave_header.wave_format,format_to_str(this_shn->wave_header.wave_format));
+			shn_debug("while processing '%s': unsupported format 0x%04x (%s) - only PCM data is supported at this time",
+				this_shn->wave_header.filename,this_shn->wave_header.wave_format,shn_format_to_str(this_shn->wave_header.wave_format));
                         return 0;
 	}
 
-	this_shn->wave_header.channels = uchar_to_ushort_le(this_shn->vars.header+cur);
+	this_shn->wave_header.channels = shn_uchar_to_ushort_le(this_shn->vars.header+cur);
 	cur += 2;
-	this_shn->wave_header.samples_per_sec = uchar_to_ulong_le(this_shn->vars.header+cur);
+	this_shn->wave_header.samples_per_sec = shn_uchar_to_ulong_le(this_shn->vars.header+cur);
 	cur += 4;
-	this_shn->wave_header.avg_bytes_per_sec = uchar_to_ulong_le(this_shn->vars.header+cur);
+	this_shn->wave_header.avg_bytes_per_sec = shn_uchar_to_ulong_le(this_shn->vars.header+cur);
 	cur += 4;
-	this_shn->wave_header.block_align = uchar_to_ushort_le(this_shn->vars.header+cur);
+	this_shn->wave_header.block_align = shn_uchar_to_ushort_le(this_shn->vars.header+cur);
 	cur += 2;
-	this_shn->wave_header.bits_per_sample = uchar_to_ushort_le(this_shn->vars.header+cur);
+	this_shn->wave_header.bits_per_sample = shn_uchar_to_ushort_le(this_shn->vars.header+cur);
 	cur += 2;
 
 	if (this_shn->wave_header.bits_per_sample != 8 && this_shn->wave_header.bits_per_sample != 16)
 	{
-		debug("Bits per sample is neither 8 nor 16");
-		debug("bits per sample is neither 8 nor 16");
+		shn_debug("while processing '%s': bits per sample is neither 8 nor 16",this_shn->wave_header.filename);
 		return 0;
 	}
 
@@ -177,10 +172,10 @@ int verify_header(shn_file *this_shn)
 	{
 		cur += 4;
 
-		l = uchar_to_ulong_le(this_shn->vars.header+cur);
+		l = shn_uchar_to_ulong_le(this_shn->vars.header+cur);
 		cur += 4;
 
-		if (WAVE_DATA == uchar_to_ulong_le(this_shn->vars.header+cur-8))
+		if (WAVE_DATA == shn_uchar_to_ulong_le(this_shn->vars.header+cur-8))
 			break;
 
 		cur += l;
@@ -217,13 +212,13 @@ int verify_header(shn_file *this_shn)
 	if ((ulong)this_shn->wave_header.header_size + this_shn->wave_header.data_size < this_shn->wave_header.total_size)
 		this_shn->wave_header.problems |= PROBLEM_EXTRA_CHUNKS;
 
-	length_to_str(this_shn);
+	shn_length_to_str(this_shn);
 
 	/* header looks ok */
 	return 1;
 }
 
-char *format_to_str(ushort format)
+char *shn_format_to_str(ushort format)
 {
   switch (format) {
     case WAVE_FORMAT_UNKNOWN:
